#!/usr/bin/env python

"""
test_textmetric
-----------------

Tests for the `textmetric` module.
"""

import unittest

from textmetric.density import ttr


class TestTextmetric(unittest.TestCase):

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_000_ttr(self):
        with self.assertRaises(ValueError):
            ttr.measure('')

    def test_001_ttr(self):
        self.assertEqual(ttr.measure('A'), 1.0)

    def test_002_ttr(self):
        self.assertEqual(ttr.measure('A A'), 0.5)


if __name__ == '__main__':
    import sys
    sys.exit(unittest.main())



#!/usr/bin/env python

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = []

test_requirements = []

setup(
    name='textmetric',
    version='0.1.0',
    description='Python implementations of common text metric algorithms.',
    long_description=readme + '\n\n' + history,
    author='Stefan Fischer',
    author_email='sfischer13@ymail.com',
    url='https://github.com/sfischer13/python-textmetric',
    packages=[
        'textmetric',
    ],
    package_dir={'textmetric': 'textmetric'},
    include_package_data=True,
    install_requires=requirements,
    license='MIT',
    zip_safe=False,
    keywords='text metric density readability TTR',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: Implementation',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Text Processing',
        'Topic :: Text Processing :: Linguistic',
    ],
    test_suite='tests',
    tests_require=test_requirements)
